<?php

namespace GGM\ProductManagerImplementation\ProductManagerMagento2;

use Magento\Backend\Helper\Data;
use Magento\Catalog\Model\Category;
use Magento\Catalog\Model\Product;
use Magento\Framework\Registry;
use Magento\Store\Model\StoreManager;

/**
 * Class OpenInMagentoHelper
 */
class OpenInMagentoHelper
{
    protected $_storeManager;
    protected $_productModel;
    protected $_categoryModel;
    protected $_registry;
    protected $_backendHelper;

    public function __construct(
        StoreManager $storeManager,
        Product $productModel,
        Category $categoryModel,
        Registry $registry,
        Data $backendHelper
    ) {
        $this->_storeManager = $storeManager;
        $this->_productModel = $productModel;
        $this->_categoryModel = $categoryModel;
        $this->_registry = $registry;
        $this->_backendHelper = $backendHelper;
    }

    // EDIT PRODUCT OR CATEGORY IN MAGENTO
    public function openInMagento($action, $id, $storeId)
    {
        if (!is_numeric($id) || $id < 0 || $id != round($id)) {
            return;
        }

        if ($action == 'editproduct') {
            $path = $this->_backendHelper->getUrl(
                'catalog/product/edit',
                array('id' => $id)
            );

            header('Location: ' . $path);
        }

        if ($action == 'editcategory') {
            $path = $this->_backendHelper->getUrl(
                'catalog/category/edit',
                array('id' => $id)
            );

            header('Location: ' . $path);
        }

        if ($action == 'viewproduct') {
            $this->_storeManager->setCurrentStore($storeId);

            $product = $this->_productModel->load($id);
            $categories = $product->getCategoryIds();

            if (count($categories) > 0) {
                $category_id = current($categories);
                $category = $this->_categoryModel->load($category_id);

                $this->_registry->unregister('current_category');
                $this->_registry->register('current_category', $category);
            }

            $path = $product->getProductUrl(true);

            header('Location: ' . $path);
        }

        if ($action == 'viewcategory') {
            $this->_storeManager->setCurrentStore($storeId);

            $category = $this->_categoryModel->load($id);
            $path = $category->getUrl();

            header('Location: ' . $path);
        }

        exit();
    }
}