<?php

namespace GGM\ProductManagerImplementation\ProductManagerMagento2;

use Exception;
use Magento\Framework\App\ResourceConnection;
use Magento\Store\Model\StoreManager;
use stdClass;
use Zend_Db;
use Main\Support\Root\Logger;

/**
 * Class ProductManagerDatabaseConnectionHelper
 */
class ProductManagerDatabaseConnectionHelper
{
    /**
     * @var StoreManager
     */
    protected $storeManager;

    /**
     * @var ResourceConnection
     */
    protected $resourceConnection;

    /**
     * @var
     */
    protected $connection;

    /**
     * @var
     */
    protected $databaseAPI;

    /**
     * ProductManagerDatabaseConnectionHelper constructor.
     *
     * @param StoreManager $storeManager
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        StoreManager $storeManager,
        ResourceConnection $resourceConnection
    ) {
        $this->storeManager = $storeManager;
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * @param $jsonRpcResult
     * @param $databaseAPI
     *
     * @return void
     */
    public function executeDatabaseConnection($jsonRpcResult, $databaseAPI)
    {
        $this->databaseAPI = $databaseAPI;
        $jsonRpcResult->result = $databaseAPI;
    }

    /**
     * @return void
     */
    public function closeConnection()
    {
        if ($this->connection) {
            $this->connection->closeConnection();
        }
    }

    /**
     * @param $jsonRpcResult
     * @param $sql
     * @param $binds
     * @param $saveLastInsertId
     *
     * @return void
     */
    public function pdoExecuteSqlQuery(
        &$jsonRpcResult,
        $sql,
        $binds,
        $saveLastInsertId
    ) {
        if (!$this->connection) {
            $this->connection = $this->resourceConnection
                ->getConnection(ResourceConnection::DEFAULT_CONNECTION);
        }

        try {
            if (count($binds) > 0) {
                $query = $this->connection->query($sql, $binds);
            } else {
                $query = $this->connection->query($sql);
            }

            if ($saveLastInsertId) {
                $table = preg_replace('/^.*INTO `(.*?)`.*$/i', '\\1', $sql);
                $lastInsertId = $this->connection->lastInsertId($table);
                $jsonRpcResult->lastInsertId = $lastInsertId;
            }

            if (!$query) {
                $jsonRpcResult->error = $query->errorInfo();
                Logger::instance('pm_debug_')
                    ->log($query->errorInfo());
            } else {
                if (preg_match('/^(SELECT|SHOW)/i', $sql)) {
                    $jsonRpcResult->result = new stdClass();
                    $jsonRpcResult->result->rows = $query
                        ->fetchAll(Zend_Db::FETCH_NUM);
                } else {
                    $jsonRpcResult->result = $query->rowCount();
                }
            }
        } catch (Exception $e) {
            $jsonRpcResult->error = $e->getMessage();
            Logger::instance('pm_debug_')
                ->log($e->getMessage());
        }
    }
}